# Amulet-pybind11-extensions

This library is an extension to pybind11 to fix some simple issues and add some useful extension classes.

This code is subject to change.

If you want to use it, target a specific commit so that changes don't break your code.
